@@ -4,7 +4,7 @@ use strict;
 use warnings;
 use parent 'PDL';
 
-our $VERSION = '0.002';
+our $VERSION = '0.003';
 
 use Scalar::Util 'looks_like_number';
 use POSIX ();
@@ -447,8 +447,9 @@ sub dt_diff {
 
 sub dt_periodicity {
   my $self = shift;
-  my $freq = $self->dt_diff->median;
-  return '' if $freq eq 'BAD';
+  return '' if !$self->is_increasing && !$self->is_decreasing;
+  my $freq = $self->qsort->dt_diff->median;
+  return '' if $freq eq 'BAD' || $freq < 0;
   if ($freq < 1_000 ) {
     # $freq < 1 millisecond
     return "microsecond";
